@@ -33,6 +33,16 @@ class Index:
         """Support str()."""
         return "(" + ", ".join(map(str, self.names)) + ")"
 
+    @property
+    def nlevels(self) -> int:
+        """Return the number of index levels."""
+        return len(self._parent._index)
+
+    @property
+    def empty(self) -> bool:
+        """Return value indicating whether the number of rows is zero."""
+        return self._parent.empty
+
     def __sentry_repr__(self):
         """Support Sentry."""
         return str(self)
